@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::PERLANCAR::MetaResources;
 
-our $DATE = '2018-09-08'; # DATE
-our $VERSION = '0.040'; # VERSION
+our $DATE = '2020-10-27'; # DATE
+our $VERSION = '0.041'; # VERSION
 
 use 5.010001;
 use strict;
@@ -99,13 +99,14 @@ sub _build__github {
     die "GitHubMeta: no github host found in URL '$url'\n"
         unless $url =~ m!(:(//)?|\@)github\.com!i;
 
-    my ($account, $project) = ($url =~ m{[:/](.+)/(.+)\.git$});
+    my ($account, $project) = ($url =~ m{[:/]([^/]+)/([^/]+?)(?:\.git)?$});
 
     die "GitHubMeta: no github account name found in URL '$url'\n"
         unless $account and length $account;
     die "GitHubMeta: no github repository (project) found in URL '$url'\n"
         unless $project and length $project;
 
+    $self->log_debug("github account: $account, github project: $project");
     return { account => $account, project => $project };
 }
 
@@ -176,7 +177,7 @@ Dist::Zilla::Plugin::PERLANCAR::MetaResources - Set meta resources for dists
 
 =head1 VERSION
 
-This document describes version 0.040 of Dist::Zilla::Plugin::PERLANCAR::MetaResources (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-MetaResources), released on 2018-09-08.
+This document describes version 0.041 of Dist::Zilla::Plugin::PERLANCAR::MetaResources (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-MetaResources), released on 2020-10-27.
 
 =head1 SYNOPSIS
 
@@ -218,7 +219,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
